==> smuxi_0.6.3.orig.tar.gz: smuxi-0.6.3/src/Engine-OSCAR/AssemblyInfo.cs <==
/*
 * $Id: AssemblyInfo.cs 211 2007-08-03 18:58:27Z meebey $
 * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/AssemblyInfo.cs $
 * $Rev: 211 $
 * $Author: meebey $
 * $Date: 2007-08-03 20:58:27 +0200 (Fri, 03 Aug 2007) $
 *
 * smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;

[assembly: AssemblyTitle("smuxi - OSCAR protocol support for engine")]
[assembly: AssemblyCopyright("2007-2008 (C) Mirco Bauer <meebey@meebey.net>")]

[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]

[assembly: CLSCompliant(true)]
[assembly: ComVisible(false)]

==> smuxi_0.8.9.2.orig.tar.gz: smuxi-0.8.9.2/src/Engine-OSCAR/AssemblyInfo.cs <==
/*
 * $Id: AssemblyInfo.cs 211 2007-08-03 18:58:27Z meebey $
 * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/AssemblyInfo.cs $
 * $Rev: 211 $
 * $Author: meebey $
 * $Date: 2007-08-03 20:58:27 +0200 (Fri, 03 Aug 2007) $
 *
 * Smuxi - Smart MUltipleXed Irc
 *
 * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
 *
 * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

using System;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;

[assembly: AssemblyTitle("Smuxi - OSCAR protocol support for engine")]
[assembly: AssemblyCopyright("2007-2008 (C) Mirco Bauer <meebey@meebey.net>")]

[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]

[assembly: CLSCompliant(true)]
[assembly: ComVisible(false)]
